@@ -21,11 +21,12 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
-#ifndef _STRINGREPLACERCONF_H_
-#define _STRINGREPLACERCONF_H_
+#ifndef STRINGREPLACERCONF_H
+#define STRINGREPLACERCONF_H
 
 // Qt includes.
 #include <QtGui/QWidget>
+#include <QtCore/QStringList>
 
 // KDE includes.
 #include <kconfig.h>
@@ -48,7 +49,7 @@ class StringReplacerConf : public KttsFilterConf, public Ui::StringReplacerConfW
         /**
         * Constructor 
         */
-        explicit StringReplacerConf( QWidget *parent, const QStringList &args = QStringList() );
+        explicit StringReplacerConf( QWidget *parent, const QVariantList &args = QVariantList() );
 
         /**
         * Destructor 
@@ -155,4 +156,4 @@ class StringReplacerConf : public KttsFilterConf, public Ui::StringReplacerConfW
         QStringList m_languageCodeList;
 };
 
-#endif  //_STRINGREPLACERCONF_H_
+#endif  //STRINGREPLACERCONF_H
